==> haskell-dependent-map-0.4.0.0-267-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dependent-map
version:              0.4.0.0
visibility:           public
id:                   dependent-map-0.4.0.0-IfZBwge4m8A7J8Apotf6sC
key:                  dependent-map-0.4.0.0-IfZBwge4m8A7J8Apotf6sC
license:              LicenseRef-OtherLicense
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/dependent-map
synopsis:             Dependent finite maps (partial dependent products)
description:
    Provides a type called @DMap@ which generalizes
    @Data.Map.Map@, allowing keys to specify the type
    of value that can be associated with them.

category:             Data, Dependent Types
abi:                  2a13506d8e41591fd1157807c78b7f29
exposed:              True
exposed-modules:
    Data.Dependent.Map Data.Dependent.Map.Internal
    Data.Dependent.Map.Lens

hidden-modules:       Data.Dependent.Map.PtrEquality
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dependent-map-0.4.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dependent-map-0.4.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dependent-map-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-map
hs-libraries:         HSdependent-map-0.4.0.0-IfZBwge4m8A7J8Apotf6sC
depends:
    base-4.17.2.1 constraints-extras-0.4.0.1-HFOlgCLcL9l1yGPzAZaTYL
    containers-0.6.7 dependent-sum-0.7.2.0-9dR8uTFsTU2ADFrLHiicbI

haddock-interfaces:
    /usr/share/doc/haskell-dependent-map/html/dependent-map.haddock

haddock-html:         /usr/share/doc/haskell-dependent-map/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dependent-map-0.4.0.0-268-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dependent-map
version:              0.4.0.0
visibility:           public
id:                   dependent-map-0.4.0.0-9nsLLuPdKK7JpvnlvwW06g
key:                  dependent-map-0.4.0.0-9nsLLuPdKK7JpvnlvwW06g
license:              LicenseRef-OtherLicense
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/dependent-map
synopsis:             Dependent finite maps (partial dependent products)
description:
    Provides a type called @DMap@ which generalizes
    @Data.Map.Map@, allowing keys to specify the type
    of value that can be associated with them.

category:             Data, Dependent Types
abi:                  4fc09db27947b1b6247c6e27553549f6
exposed:              True
exposed-modules:
    Data.Dependent.Map Data.Dependent.Map.Internal
    Data.Dependent.Map.Lens

hidden-modules:       Data.Dependent.Map.PtrEquality
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dependent-map-0.4.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dependent-map-0.4.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dependent-map-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-map
hs-libraries:         HSdependent-map-0.4.0.0-9nsLLuPdKK7JpvnlvwW06g
depends:
    base-4.17.2.1 constraints-extras-0.4.0.1-DOqGmGE57y3Am5LWu0yrOo
    containers-0.6.7 dependent-sum-0.7.2.0-5fTblGalXlE75UjMStPu4v

haddock-interfaces:
    /usr/share/doc/haskell-dependent-map/html/dependent-map.haddock

haddock-html:         /usr/share/doc/haskell-dependent-map/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
